[![pypi](https://img.shields.io/pypi/v/rubin-scheduler.svg)](https://pypi.org/project/rubin-scheduler/)
 [![Conda Version](https://img.shields.io/conda/vn/conda-forge/rubin-scheduler.svg)](https://anaconda.org/conda-forge/rubin-scheduler) <br>
[![Run CI](https://github.com/lsst/rubin_scheduler/actions/workflows/test_and_build.yaml/badge.svg)](https://github.com/lsst/rubin_scheduler/actions/workflows/test_and_build.yaml)
[![Build and Upload Docs](https://github.com/lsst/rubin_scheduler/actions/workflows/build_docs.yaml/badge.svg)](https://github.com/lsst/rubin_scheduler/actions/workflows/build_docs.yaml)


[![DOI](https://zenodo.org/badge/712606243.svg)](https://zenodo.org/doi/10.5281/zenodo.10076770)

# rubin_scheduler

Feature Based Scheduler for Vera C. Rubin Observatory's Legacy Survey of Space and Time (LSST).

This repository contains the scheduling algorithms for the LSST, as implemented in the Feature Based Scheduler (FBS). More documentation on the FBS is available at https://rubin-scheduler.lsst.io and in jupyter notebooks available in our [tutorials repository](https://github.com/lsst/rubin_sim_notebooks/tree/main/scheduler). 


